summaryrefslogtreecommitdiffstats
path: root/klettres
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 19:08:32 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 19:08:32 -0600
commit4c7b13d8cd49d49729801a278b5ce768406400cc (patch)
tree596f6241b14691b5324e4b775d16bb6894943264 /klettres
parent5ce07f4f6f046d00fe97a3f544993f1aac169085 (diff)
downloadtdeedu-4c7b13d8cd49d49729801a278b5ce768406400cc.tar.gz
tdeedu-4c7b13d8cd49d49729801a278b5ce768406400cc.zip
Rename KDEHOME and KDEDIR
Diffstat (limited to 'klettres')
-rw-r--r--klettres/klettres/klettres.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/klettres/klettres/klettres.cpp b/klettres/klettres/klettres.cpp
index d1f96e59..d1d5e550 100644
--- a/klettres/klettres/klettres.cpp
+++ b/klettres/klettres/klettres.cpp
@@ -103,7 +103,7 @@ void KLettres::findLanguages()
if (m_languages.isEmpty()) return;
Prefs::setLanguages(m_languages);
Prefs::writeConfig();
//find duplicated entries in KDEDIR and KDEHOME
TQStringList temp_languages;
for (uint i=0; i<m_languages.count(); i++)
{
@@ -129,7 +129,7 @@ void KLettres::findLanguages()
if (!config->readEntry(tmp))
config->writeEntry(tmp, TQString(TQDate::tqcurrentDate().toString()));
}
//we look in $KDEDIR/share/locale/all_languages from /tdelibs/tdecore/all_languages
//to find the name of the country
//corresponding to the code and the language the user set
KConfig entry(locate("locale", "all_languages"));
@@ -173,9 +173,9 @@ bool KLettres::loadLayout(TQDomDocument &layoutDocument)
//if xml file is not found, program exits
if (!layoutFile.exists())
{
- kdWarning() << "sounds.xml file not found in $KDEDIR/share/apps/klettres/"+Prefs::language() << endl;
+ kdWarning() << "sounds.xml file not found in $TDEDIR/share/apps/klettres/"+Prefs::language() << endl;
TQString mString=i18n("The file sounds.xml was not found in\n"
- "$KDEDIR/share/apps/klettres/\n\n"
+ "$TDEDIR/share/apps/klettres/\n\n"
"Please install this file and start KLettres again.\n\n");
KMessageBox::information( this, mString,"KLettres - Error" );
kapp->quit();//exit(1);
@@ -458,7 +458,7 @@ void KLettres::loadLangToolBar()
if (!myFile.exists())
{
- TQString mString=i18n("File $KDEDIR/share/apps/klettres/%1.txt not found;\n"
+ TQString mString=i18n("File $TDEDIR/share/apps/klettres/%1.txt not found;\n"
"please check your installation.").tqarg(m_languages[Prefs::languageNumber()]);
KMessageBox::sorry( this, mString,
i18n("Error") );
@@ -103,7 +103,7 @@ void KLettres::findLanguages()
Prefs::setLanguages(m_languages);
Prefs::writeConfig();
- //find duplicated entries in KDEDIR and KDEHOME
+ //find duplicated entries in TDEDIR and TDEHOME
TQStringList temp_languages;
for (uint i=0; i<m_languages.count(); i++)
@@ -129,7 +129,7 @@ void KLettres::findLanguages()
config->writeEntry(tmp, TQString(TQDate::tqcurrentDate().toString()));
}
- //we look in $KDEDIR/share/locale/all_languages from /tdelibs/tdecore/all_languages
+ //we look in $TDEDIR/share/locale/all_languages from /tdelibs/tdecore/all_languages
//to find the name of the country
//corresponding to the code and the language the user set